# HOW TO NORMALIZE DATA USING A "HIGH" AND "LOW" SCORE FOR EACH ITEM FROM EACH SUBJECT

# We will load the Experiment 2 data (from Kapogianni) either directly from the Internet:

ex2 <- read.csv("http://www.danielezrajohnson.com/ex2.csv")

# Or if you've unzipped the .zip file into a directory, you can locate and load the file like this:

ex2 <- read.csv(file.choose())

# Let's look at the columns of this data file:

names(ex2)

# "Implication"   "Cancellation"  "Group"         "Subject"       "Item"        "Acceptability"

# Certain columns are numeric, but conceptually they are really factors. We fix this as follows:

ex2$Group <- as.factor(ex2$Group)
ex2$Subject <- as.factor(ex2$Subject)
ex2$Item <- as.factor(ex2$Item)

# The overall purpose of this analysis is to look at the influence of Implication on Acceptability,
# but only for the Cancellation group called "Critical". The other levels of Cancellation, "Acceptable"
# and "Unacceptable", are essentially filler items, but they are also intended to be used to calibrate
# the range of likely responses for a given Item. 

# The purpose of this script is to perform this normalization. There seem to be two ways to accomplish
# this. The simpler way is to take each Item and establish the mean for "Unacceptable" and the mean for 
# "Acceptable". We can then assign 0 to the lower mean and 1 to the higher mean. Each "Critical"
# acceptability rating would be rescaled to this scale. A few values might be lower than 0 or higher
# than 1, but this is not a problem.

# Let's call this type of normalized acceptability "Acceptability2". We will create a new column for it.
# In order to do this, we will create a multi-line script with a for-loop in it.

for (i in 1:72){
	low <- mean(ex2$Acceptability[ex2$Item == i & ex2$Cancellation == "Unacceptable"])
	high <- mean(ex2$Acceptability[ex2$Item == i & ex2$Cancellation == "Acceptable"])
	range <- high - low
	ex2$Acceptability2[ex2$Item == i & ex2$Cancellation == "Critical"] <- 
		(ex2$Acceptability[ex2$Item == i & ex2$Cancellation == "Critical"] - low) / range}
		
# We can see here that when it comes to programming in R, there is quite a bit of syntax that needs
# to be learned! The official R manual is http://cran.r-project.org/doc/manuals/R-intro.pdf. Two other
# recommended books are http://www.amazon.com/dp/141297514X/ref=cm_sw_su_dp (by Fox), and
# http://www.amazon.com/Introductory-Statistics-R-Peter-Dalgaard/dp/0387954759 (by Dalgaard).

# In order to prepare the data for the next step -- the analysis of the effect of Implication on 
# Acceptability -- we can throw away everything except the "Critical" data, as follows:

ex2.critical <- ex2[ex2$Cancellation == "Critical", ]

nrow(ex2.critical)	# 720 <- this is correct, 72 items, each judged by 10 subjects (out of 30 subjects)

# You may want to save this file. You can save the data frame* as a .csv file as follows:
# *data frame is what R calls the usual data structure with rows and named columns.

write.csv(ex2.critical, "ex2.critical.csv", row.names = F)